@@ -136,3 +136,11 @@ class DiskNotFound(NotFound):
 
 class HyperVRemoteFXException(HyperVException):
     pass
+
+
+class HyperVClusterException(HyperVException):
+    pass
+
+
+class JobTerminateFailed(HyperVException):
+    msg_fmt = _("Could not terminate the requested job(s).")
