@@ -19,11 +19,23 @@ from oslotest import base
 from six.moves import builtins
 
 
+class FakeWMIExc(Exception):
+    def __init__(self, hresult=None):
+        excepinfo = [None] * 5 + [hresult]
+        self.com_error = mock.Mock(excepinfo=excepinfo)
+        super(FakeWMIExc, self).__init__()
+
+
 class OsWinBaseTestCase(base.BaseTestCase):
     def setUp(self):
         super(OsWinBaseTestCase, self).setUp()
 
         self._mock_wmi = mock.MagicMock()
+        self._mock_wmi.x_wmi = FakeWMIExc
+
+        mock_os = mock.MagicMock(Version='6.3.0')
+        self._mock_wmi.WMI.return_value.Win32_OperatingSystem.return_value = (
+            [mock_os])
         wmi_patcher = mock.patch.object(builtins, 'wmi', create=True,
                                         new=self._mock_wmi)
         wmi_patcher.start()
