@@ -153,29 +153,6 @@ class ISCSIInitiatorUtilsTestCase(test_base.OsWinBaseTestCase):
         self.assertRaises(exceptions.Win32Exception, fake_func,
                           self._initiator)
 
-    @mock.patch('time.sleep')
-    def test_retry_for_err_codes_decorator(self, mock_sleep):
-        err_code = 1
-        max_retry_count = 5
-        retry_interval = 1
-
-        raised_exc = exceptions.Win32Exception(message='fake_exc',
-                                               error_code=err_code)
-        side_effect = [raised_exc] * max_retry_count
-        side_effect.append(mock.sentinel.ret_val)
-        func_side_effect = mock.Mock(side_effect=side_effect)
-
-        @iscsi_utils.retry_for_err_codes(error_codes=err_code,
-                                         max_retry_count=max_retry_count,
-                                         retry_interval=retry_interval)
-        def fake_func(*args, **kwargs):
-            return func_side_effect(*args, **kwargs)
-
-        ret_val = fake_func()
-        self.assertEqual(mock.sentinel.ret_val, ret_val)
-        mock_sleep.assert_has_calls(
-            [mock.call(retry_interval)] * max_retry_count)
-
     def test_get_items_from_buff(self):
         fake_buff_contents = 'fake_buff_contents'
         fake_buff = (ctypes.c_wchar * len(fake_buff_contents))()
@@ -374,19 +351,19 @@ class ISCSIInitiatorUtilsTestCase(test_base.OsWinBaseTestCase):
                        '_get_iscsi_sessions')
     def test_get_iscsi_target_sessions(self, mock_get_iscsi_sessions,
                                         target_sessions_found=True):
-        fake_session = mock.Mock(TargetNodeName=mock.sentinel.target_name,
+        fake_session = mock.Mock(TargetNodeName="FAKE_TARGET_NAME",
                                  ConnectionCount=1)
         fake_disconn_session = mock.Mock(
-            TargetNodeName=mock.sentinel.target_name,
+            TargetNodeName="fake_target_name",
             ConnectionCount=0)
-        other_session = mock.Mock(TargetNodeName=mock.sentinel.other_target,
+        other_session = mock.Mock(TargetNodeName="other_target_name",
                                   ConnectionCount=1)
 
         sessions = [fake_session, fake_disconn_session, other_session]
         mock_get_iscsi_sessions.return_value = sessions
 
         resulted_tgt_sessions = self._initiator._get_iscsi_target_sessions(
-            mock.sentinel.target_name)
+            "fake_target_name")
 
         self.assertEqual([fake_session], resulted_tgt_sessions)
 
