@@ -16,6 +16,7 @@ import os
 
 import mock
 from oslotest import base
+import six
 
 from os_win import constants
 from os_win import exceptions
@@ -291,6 +292,7 @@ class VHDUtilsTestCase(base.BaseTestCase):
         mock_open.return_value = mock.sentinel.handle
         mock_get_vhd_info_member.return_value = fake_vhd_info
 
+        expected_open_flag = vdisk_const.OPEN_VIRTUAL_DISK_FLAG_NO_PARENTS
         expected_access_mask = (vdisk_const.VIRTUAL_DISK_ACCESS_GET_INFO |
                                 vdisk_const.VIRTUAL_DISK_ACCESS_DETACH)
 
@@ -300,6 +302,7 @@ class VHDUtilsTestCase(base.BaseTestCase):
         self.assertEqual(fake_vhd_info, ret_val)
         mock_open.assert_called_once_with(
             mock.sentinel.vhd_path,
+            open_flag=expected_open_flag,
             open_access_mask=expected_access_mask)
         self._vhdutils._get_vhd_info_member.assert_called_once_with(
             mock.sentinel.handle,
@@ -618,10 +621,12 @@ class VHDUtilsTestCase(base.BaseTestCase):
         expected_vhd_size = root_vhd_size - expected_md_size
         self.assertEqual(expected_vhd_size, real_size)
 
+    @mock.patch.object(vhdutils.VHDUtils, '_get_vhdx_block_size')
     @mock.patch.object(vhdutils.VHDUtils, '_get_vhdx_log_size')
     @mock.patch.object(vhdutils.VHDUtils, '_get_vhdx_metadata_size_and_offset')
     def test_get_vhdx_internal_size(self, mock_get_vhdx_md_sz_and_off,
-                                    mock_get_vhdx_log_sz):
+                                    mock_get_vhdx_log_sz,
+                                    mock_get_vhdx_block_size):
         self._mock_open()
         fake_log_sz = 1 << 20
         fake_block_sz = 32 << 20
@@ -631,15 +636,16 @@ class VHDUtilsTestCase(base.BaseTestCase):
         # We expect less than a block to be reserved for internal metadata.
         expected_max_int_sz = new_vhd_sz - fake_block_sz
 
-        fake_vhd_info = dict(SectorSize=fake_logical_sector_sz,
-                             BlockSize=fake_block_sz)
+        fake_vhd_info = dict(SectorSize=fake_logical_sector_sz)
 
+        mock_get_vhdx_block_size.return_value = fake_block_sz
         mock_get_vhdx_log_sz.return_value = fake_log_sz
         mock_get_vhdx_md_sz_and_off.return_value = fake_md_sz, None
 
         internal_size = self._vhdutils._get_internal_vhdx_size_by_file_size(
             mock.sentinel.vhd_path, new_vhd_sz, fake_vhd_info)
 
+        self.assertIn(type(internal_size), six.integer_types)
         self.assertEqual(expected_max_int_sz, internal_size)
 
     def test_get_vhdx_internal_size_exception(self):
@@ -693,6 +699,18 @@ class VHDUtilsTestCase(base.BaseTestCase):
         self.assertEqual(1, md_sz)
         self.assertEqual(1, md_offset)
 
+    @mock.patch.object(vhdutils.VHDUtils,
+                       '_get_vhdx_metadata_size_and_offset')
+    def test_get_block_size(self, mock_get_md_sz_and_offset):
+        mock_get_md_sz_and_offset.return_value = (mock.sentinel.md_sz, 1024)
+        fake_block_size = bytearray(b'\x01\x00\x00\x00')
+        fake_offset = bytearray(b'\x02\x00\x00\x00')
+        mock_handle = self._get_mock_file_handle(fake_offset,
+                                                 fake_block_size)
+
+        block_size = self._vhdutils._get_vhdx_block_size(mock_handle)
+        self.assertEqual(block_size, 1)
+
     @mock.patch.object(vhdutils.VHDUtils, 'convert_vhd')
     @mock.patch.object(os, 'unlink')
     @mock.patch.object(os, 'rename')
