@@ -130,16 +130,10 @@ utils_map = {
             'min_version': 6.2,
             'max_version': None,
             'path': 'os_win.utils.compute.clusterutils.ClusterUtils'}},
-    'cluster_failover_monitor': {
-        'ClusterFailoverMonitor': {
-            'min_version': 6.2,
-            'max_version': None,
-            'path': 'os_win.utils.compute.clusterutils.ClusterFailoverMonitor'
-        }},
 }
 
 
-def _get_class(class_type):
+def _get_class(class_type, *args, **kwargs):
     if class_type not in utils_map:
         raise exceptions.HyperVException(_('Class type %s does '
                                            'not exist') % class_type)
@@ -154,7 +148,8 @@ def _get_class(class_type):
         if (utils_class['min_version'] <= windows_version and
                 (utils_class['max_version'] is None or
                  windows_version < utils_class['max_version'])):
-            return importutils.import_object(utils_class['path'])
+            return importutils.import_object(utils_class['path'],
+                                             *args, **kwargs)
 
     raise exceptions.HyperVException(_('Could not find any %(class)s class for'
         'this Windows version: %(win_version)s')
@@ -162,7 +157,7 @@ def _get_class(class_type):
 
 
 def get_vmutils(host='.'):
-    return _get_class(class_type='vmutils')
+    return _get_class(class_type='vmutils', host=host)
 
 
 def get_vhdutils():
@@ -226,7 +221,3 @@ def get_diskutils():
 
 def get_clusterutils():
     return _get_class(class_type='clusterutils')
-
-
-def get_cluster_failover_monitor():
-    return _get_class(class_type='cluster_failover_monitor')
